package data

import (
	"time"

	"gorm.io/driver/mysql"

	"demo/internal/conf"

	"github.com/go-kratos/kratos/v2/log"
	"github.com/google/wire"
	"github.com/sirupsen/logrus"
	"gorm.io/gorm"
	"gorm.io/gorm/logger"
)

// ProviderSet is data providers.
var ProviderSet = wire.NewSet(NewData, NewCampaignRepo, NewAdRepo, NewCreativeRepo)

// Data .
type Data struct {
	db *gorm.DB
}

// NewData .
func NewData(c *conf.Data, logger log.Logger) (*Data, func(), error) {
	cleanup := func() {
		log.NewHelper(logger).Info("closing the data resources")
	}
	db, err := newDb(c)
	if err != nil {
		return nil, cleanup, err
	}
	return &Data{db: db}, cleanup, nil
}

func newDb(c *conf.Data) (*gorm.DB, error) {
	db, err := gorm.Open(mysql.New(mysql.Config{
		DriverName: c.Database.Driver,
		DSN:        c.Database.Source,
	}), &gorm.Config{
		Logger: NewGormLogger(),
	})
	if err != nil {
		return nil, err
	}
	sqlDb, err := db.DB()
	if err != nil {
		return nil, err
	}
	// the maximum number of connections in the idle connection pool.
	if c.Database.MaxIdle > 0 {
		sqlDb.SetMaxIdleConns(int(c.Database.MaxIdle))
	}
	// the maximum number of open connections to the database.
	if c.Database.MaxOpen > 0 {
		sqlDb.SetMaxOpenConns(int(c.Database.MaxOpen))
	}
	// the maximum amount of time a connection may be reused.
	if c.Database.MaxLifetime != nil {
		sqlDb.SetConnMaxLifetime(c.Database.MaxLifetime.AsDuration())
	}
	return db, nil
}

func NewGormLogger() logger.Interface {
	return logger.New(logrus.StandardLogger(), logger.Config{
		SlowThreshold:             time.Second,
		IgnoreRecordNotFoundError: true,
		LogLevel:                  logger.Info,
	})
}
