package mid

import (
	"fmt"
	"strings"
	"time"

	"github.com/gin-gonic/gin"
	"github.com/google/uuid"

	"demo/internal/util"
)

type Common struct {
}

// SetRequestId 设置接口的request_id
func (p *Common) SetRequestId(c *gin.Context) {
	reqId := strings.Replace(uuid.New().String(), "-", "", -1)
	now := time.Now().Format("20060102150405")
	c.Set(util.RequestKey, fmt.Sprintf("%s%s", now, reqId))
}

// PassMethods 过滤所有的Options, Head Method Requests
func (p *Common) PassMethods(c *gin.Context) {
	if c.Request.Method == "OPTIONS" || c.Request.Method == "HEAD" {
		c.AbortWithStatusJSON(200, gin.H{"success": "success"})
		return
	}
}

// Cors 允许服务器跨域访问
func (p *Common) Cors(c *gin.Context) {
	c.Header("Access-Control-Allow-Origin", "*")
	c.Header("Access-Control-Allow-Methods", "OPTIONS,HEAD,GET,POST,DELETE,PUT,PATCH")
	c.Header("Access-Control-Allow-Headers", "Authorization,Content-Type,Content-Range,Content-Disposition,token,access-token,device,x-requested-with")
}
