package router

import (
	"net/http"

	"github.com/gin-contrib/pprof"
	"github.com/gin-gonic/gin"

	"github.com/swaggo/files"
	"github.com/swaggo/gin-swagger"

	_ "demo/docs"
	"demo/internal/router/mid"
	"demo/internal/service"
)

type Web struct {
	Common  *mid.Common
	Jwt     *mid.Jwt
	Greeter *service.GreeterService
	Report  *service.ReportService
}

// RouterInit
// @title Ads Api Docs
// @version 1.0
// @description swagger api for [ads](https://test.adsdesk.cn/)
// @host 127.0.0.1:8000
// @BasePath /api/v1
// @securityDefinitions.apikey ApiKeyAuth
// @in header
// @name token
func (p *Web) RouterInit(engine *gin.Engine) {
	engine.Use(p.Common.SetRequestId, p.Common.Cors, p.Common.PassMethods)
	engine.NoRoute(func(c *gin.Context) {
		c.JSON(http.StatusNotFound, gin.H{"code": "404", "message": "Page not found"})
	})
	if gin.Mode() != gin.ReleaseMode {
		engine.GET("/swagger/*any", ginSwagger.WrapHandler(swaggerFiles.Handler))
	}
	// add pprof to look at the heap,a 30-second CPU and so on profile
	// eg: go tool pprof http://localhost:8000/api/pprof/profile
	pprof.Register(engine, "/api/pprof")
	// add api
	engine.GET("/hello/:name", p.Greeter.SayHello)
	api := engine.Group("/api/v1", p.Jwt.CheckToken)
	{
		report := api.Group("/report")
		{
			report.POST("/campaign", p.Report.ListCampaignData)
			report.POST("/ad", p.Report.ListAdData)
			report.POST("/creative", p.Report.ListCreativeData)
		}
	}
}
